@@ -20,10 +20,10 @@ class WagtailTagManagerConfig(AppConfig):
 
     @staticmethod
     def register_variables():
-        from wagtail_tag_manager.decorators import register_variable
+        from wagtail_tag_manager.utils import get_consent
         from wagtail_tag_manager.options import CustomVariable
         from wagtail_tag_manager.settings import TagTypeSettings
-        from wagtail_tag_manager.utils import get_consent
+        from wagtail_tag_manager.decorators import register_variable
 
         class TagConsentVariable(CustomVariable):
             group = _("Consent")
@@ -132,8 +132,11 @@ class WagtailTagManagerConfig(AppConfig):
             group = _("Wagtail")
 
             def get_value(self, request):
-                if hasattr(request, "site"):
-                    return getattr(request.site, "pk", "")
+                from wagtail_tag_manager.utils import get_site_for_request
+
+                site = get_site_for_request(request)
+                if site:
+                    return getattr(site, "pk", "")
                 return super().get_value(request)
 
         @register_variable
